# sha256bit
SHA256 with bit granularity for message input length.


## Build the package
````
python3 -m build
````

## Test
Tests can run without creating/installing the package:
````
python3 -m test.test
````
